@@ -61,17 +61,17 @@ void authfail_report(void)
    ouser2[0]='\0';
    oip[0]='\0';
 
-   snprintf(tmp4,sizeof(tmp4),"%s/sarg/authfail.log.unsort",TempDir);
+   snprintf(tmp4,sizeof(tmp4),"%s/authfail.log.unsort",tmp);
 
    if(authfail_count == 0) {
       unlink(tmp4);
       return;
    }
 
-   snprintf(authfail_in,sizeof(authfail_in),"%s/authfail.log",TempDir);
+   snprintf(authfail_in,sizeof(authfail_in),"%s/authfail.log",tmp);
    snprintf(report,sizeof(report),"%s/authfail.html",outdirname);
 
-   snprintf(csort,sizeof(csort),"sort -b -T \"%s\" -k 3,3 -k 5,5 -o \"%s\" \"%s\"", TempDir, authfail_in, tmp4);
+   snprintf(csort,sizeof(csort),"sort -b -T \"%s\" -k 3,3 -k 5,5 -o \"%s\" \"%s\"", tmp, authfail_in, tmp4);
    cstatus=system(csort);
    if (!WIFEXITED(cstatus) || WEXITSTATUS(cstatus)) {
       debuga(_("sort command return status %d\n"),WEXITSTATUS(cstatus));
