@@ -29,48 +29,54 @@
 
 void convlog(const char *arq, char *df, int dfrom, int duntil)
 {
-
    FILE *fp_in;
-   char buf[MAXLEN];
+   char *buf;
    char data[30];
    char dia[11];
-   char wdata[20];
    time_t tt;
    int idata=0;
    struct tm *t;
    struct getwordstruct gwarea;
+   longline line;
 
    if(arq[0] == '\0')
       arq="/var/log/squid/access.log";
 
    if((fp_in=MY_FOPEN(arq,"r"))==NULL) {
-      fprintf(stderr, "SARG: (convlog) %s: %s\n",text[8],arq);
-      exit(1);
+      debuga(_("(convlog) Cannot open log file %s - %s\n"),arq,strerror(errno));
+      exit(EXIT_FAILURE);
    }
 
-   while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
+   if ((line=longline_create())==NULL) {
+      debuga(_("Not enough memory to read the log file %s\n"),arq);
+      exit(EXIT_FAILURE);
+   }
+
+   while((buf=longline_read(fp_in,line))!=NULL) {
       getword_start(&gwarea,buf);
       if (getword(data,sizeof(data),&gwarea,' ')<0) {
-         printf("SARG: Maybe you have a broken record or garbage in your %s file.\n",arq);
-         exit(1);
+         debuga(_("Maybe you have a broken record or garbage in file %s\n"),arq);
+         exit(EXIT_FAILURE);
       }
       tt=atoi(data);
       t=localtime(&tt);
 
       if(dfrom) {
-         strftime(wdata, sizeof(wdata), "%Y%m%d", t);
-         idata=atoi(wdata);
+         idata=(t->tm_year+1900)*10000+(t->tm_mon+1)*100+t->tm_mday;
          if(idata < dfrom || idata > duntil)
             continue;
       }
 
-      if(strncmp(df,"e",1) == 0)
+      if(df[0]=='e')
          strftime(dia, sizeof(dia), "%d/%m/%Y", t);
        else
          strftime(dia, sizeof(dia), "%m/%d/%Y", t);
 
-      printf("%s %02d:%02d:%02d %s",dia,t->tm_hour,t->tm_min,t->tm_sec,gwarea.current);
+      printf("%s %02d:%02d:%02d %s\n",dia,t->tm_hour,t->tm_min,t->tm_sec,gwarea.current);
    }
 
-   fclose(fp_in);
+   longline_destroy(&line);
+   if (fclose(fp_in)==EOF) {
+      debuga(_("Failed to close file %s - %s\n"),arq,strerror(errno));
+   }
 }
