@@ -31,6 +31,7 @@ void dansguardian_log(void)
 {
 
    FILE *fp_in = NULL, *fp_ou = NULL, *fp_guard = NULL;
+   char buf[MAXLEN];
    char guard_in[MAXLEN];
    char guard_ou[MAXLEN];
    char loglocation[MAXLEN] = "/var/log/dansguardian/access.log";
@@ -39,60 +40,32 @@ void dansguardian_log(void)
    char user[MAXLEN], code1[255], code2[255];
    char ip[30];
    char wdata[127];
-   char url[MAXLEN];
-   char urly[MAXLEN];
+   char *url;
+   char tmp6[MAXLEN];
    int  idata=0;
    int cstatus;
+   int dfrom, duntil;
    struct getwordstruct gwarea;
 
-   bzero(day, 3);
-   bzero(mon, 4);
-   bzero(year, 5);
+   dfrom=(period.start.tm_year+1900)*10000+(period.start.tm_mon+1)*100+period.start.tm_mday;
+   duntil=(period.end.tm_year+1900)*10000+(period.end.tm_mon+1)*100+period.end.tm_mday;
 
-   if(strcmp(df,"e") == 0) {
-      strncpy(day,period,2);
-      strncpy(mon,period+2,3);
-      strncpy(year,period+5,4);
-      conv_month(mon);
-      sprintf(warea,"%s%s%s",year,mon,day);
-      dfrom=atoi(warea);
-      strncpy(day,period+10,2);
-      strncpy(mon,period+12,3);
-      strncpy(year,period+15,4);
-      conv_month(mon);
-      sprintf(warea,"%s%s%s",year,mon,day);
-      duntil=atoi(warea);
-   } else {
-      strncpy(day,period+7,2);
-      strncpy(mon,period+4,3);
-      strncpy(year,period,4);
-      conv_month(mon);
-      sprintf(warea,"%s%s%s",year,mon,day);
-      dfrom=atoi(warea);
-      strncpy(day,period+17,2);
-      strncpy(mon,period+14,3);
-      strncpy(year,period+10,4);
-      conv_month(mon);
-      sprintf(warea,"%s%s%s",year,mon,day);
-      duntil=atoi(warea);
-   }
-
-   sprintf(guard_in,"%s/dansguardian.unsort",tmp);
-   sprintf(guard_ou,"%s/dansguardian.log",tmp);
+   snprintf(guard_in,sizeof(guard_in),"%s/dansguardian.unsort",tmp);
+   snprintf(guard_ou,sizeof(guard_ou),"%s/dansguardian.log",tmp);
 
    if(access(DansGuardianConf, R_OK) != 0) {
-      debuga("Cannot open DansGuardian config file: %s",DansGuardianConf);
-      exit(1);
+      debuga(_("Cannot open DansGuardian config file: %s\n"),DansGuardianConf);
+      exit(EXIT_FAILURE);
    }
 
    if((fp_guard=fopen(DansGuardianConf,"r"))==NULL) {
-      fprintf(stderr, "SARG: (dansguardian) %s: %s\n",text[8],DansGuardianConf);
-      exit(1);
+      debuga(_("(dansguardian) Cannot open log file: %s\n"),DansGuardianConf);
+      exit(EXIT_FAILURE);
    }
 
    if((fp_ou=MY_FOPEN(guard_in,"a"))==NULL) {
-      fprintf(stderr, "SARG: (dansguardian) %s: %s\n",text[8],guard_in);
-      exit(1);
+      debuga(_("(dansguardian) Cannot open log file: %s\n"),guard_in);
+      exit(EXIT_FAILURE);
    }
 
    while(fgets(buf,sizeof(buf),fp_guard)!=NULL) {
@@ -102,25 +75,19 @@ void dansguardian_log(void)
       if(strstr(buf,"loglocation ") != 0) {
          getword_start(&gwarea,buf);
          if (getword_skip(MAXLEN,&gwarea,'\'')<0 || getword(loglocation,sizeof(loglocation),&gwarea,'\'')<0) {
-            printf("SARG: Maybe you have a broken record or garbage in your %s file.\n",DansGuardianConf);
-            exit(1);
+            debuga(_("Maybe you have a broken record or garbage in your %s file\n"),DansGuardianConf);
+            exit(EXIT_FAILURE);
          }
          break;
       }
    }
 
-   if(debug) {
-      getword_start(&gwarea,text[7]);
-      if (getword(urly,sizeof(urly),&gwarea,' ')<0 || getword(href,sizeof(href),&gwarea,' ')<0) {
-         printf("SARG: Maybe you have a broken record or garbage in your %s entry.\n",text[7]);
-         exit(1);
-      }
-      debuga("%s DansGuardian %s: %s",urly,gwarea.current,loglocation);
-   }
+   if(debug)
+      debuga(_("Reading DansGuardian log file: %s\n"),loglocation);
 
    if((fp_in=MY_FOPEN(loglocation,"r"))==NULL) {
-      fprintf(stderr, "SARG: (dansguardian) %s: %s\n",text[8],loglocation);
-      exit(1);
+      debuga(_("(dansguardian) Cannot open log file: %s\n"),loglocation);
+      exit(EXIT_FAILURE);
    }
 
    while(fgets(buf,sizeof(buf),fp_in) != NULL) {
@@ -130,16 +97,23 @@ void dansguardian_log(void)
       if (getword(year,sizeof(year),&gwarea,'.')<0 || getword(mon,sizeof(mon),&gwarea,'.')<0 ||
           getword(day,sizeof(day),&gwarea,' ')<0 || getword(hour,sizeof(hour),&gwarea,' ')<0 ||
           getword(user,sizeof(user),&gwarea,' ')<0 || getword(ip,sizeof(ip),&gwarea,' ')<0 ||
-          getword_skip(MAXLEN,&gwarea,'/')<0 || getword_skip(MAXLEN,&gwarea,'/')<0 ||
-          getword(url,sizeof(url),&gwarea,' ')<0 || getword_skip(255,&gwarea,' ')<0 ||
+          getword_skip(MAXLEN,&gwarea,'/')<0 || getword_skip(MAXLEN,&gwarea,'/')<0) {
+         debuga(_("Maybe you have a broken record or garbage in your %s file\n"),loglocation);
+         exit(EXIT_FAILURE);
+      }
+      if (getword_ptr(buf,&url,&gwarea,' ')<0) {
+         debuga(_("Maybe you have a broken url in your %s file\n"),loglocation);
+         exit(EXIT_FAILURE);
+      }
+      if (getword_skip(255,&gwarea,' ')<0 ||
           getword(code1,sizeof(code1),&gwarea,' ')<0 || getword(code2,sizeof(code2),&gwarea,' ')<0) {
-         printf("SARG: Maybe you have a broken record or garbage in your %s file.\n",loglocation);
-         exit(1);
+         debuga(_("Maybe you have a broken record or garbage in your %s file\n"),loglocation);
+         exit(EXIT_FAILURE);
       }
       sprintf(wdata,"%s%02d%s",year,atoi(mon),day);
       idata = atoi(wdata);
 
-      if(DansguardianIgnoreDate) {
+      if(DansguardianFilterOutDate) {
          if(idata < dfrom && idata > duntil)
             continue;
       }
@@ -157,14 +131,14 @@ void dansguardian_log(void)
    if(fp_ou) fclose(fp_ou);
 
    if(debug)
-      debuga("%s: %s",text[54],guard_ou);
+      debuga(_("Sorting file: %s\n"),guard_ou);
 
-   sprintf(tmp6,"sort -k 1,1 -k 2,2 -k 4,4 \"%s\" -o \"%s\"",guard_in, guard_ou);
+   snprintf(tmp6,sizeof(tmp6),"sort -k 1,1 -k 2,2 -k 4,4 \"%s\" -o \"%s\"",guard_in, guard_ou);
    cstatus=system(tmp6);
    if (!WIFEXITED(cstatus) || WEXITSTATUS(cstatus)) {
-      fprintf(stderr, "SARG: sort command return status %d\n",WEXITSTATUS(cstatus));
-      fprintf(stderr, "SARG: sort command: %s\n",tmp6);
-      exit(1);
+      debuga(_("sort command return status %d\n"),WEXITSTATUS(cstatus));
+      debuga(_("sort command: %s\n"),tmp6);
+      exit(EXIT_FAILURE);
    }
    unlink(guard_in);
 }
