@@ -32,11 +32,10 @@ void dansguardian_report(void)
 
    FILE *fp_in = NULL, *fp_ou = NULL;
 
-   char url[MAXLEN];
+   char buf[MAXLEN];
+   char *url;
    char dansguardian_in[MAXLEN];
-   char per[MAXLEN];
    char report[MAXLEN];
-   char period[100];
    char ip[MAXLEN];
    char rule[255];
    char oip[MAXLEN];
@@ -45,72 +44,55 @@ void dansguardian_report(void)
    char date[15];
    char date2[15];
    char hour[15];
-   char *str;
+   char ouser2[255];
    int  z=0;
    int  count=0;
    struct getwordstruct gwarea;
 
    ouser[0]='\0';
 
-   sprintf(dansguardian_in,"%s/dansguardian.log",tmp);
+   snprintf(dansguardian_in,sizeof(dansguardian_in),"%s/dansguardian.log",tmp);
    if(!dansguardian_count) {
       unlink(dansguardian_in);
       return;
    }
 
-   sprintf(per,"%s/sarg-period",dirname);
-   sprintf(report,"%s/dansguardian.html",dirname);
-
-   if ((fp_in = fopen(per, "r")) == 0) {
-      fprintf(stderr, "SARG: (dansguardian_report) %s: %s\n",text[45],per);
-      exit(1);
-   }
-
-   if (!fgets(period,sizeof(period),fp_in)) {
-      fprintf(stderr,"SARG: (dansguardian_report) read error in %s\n",per);
-      exit(1);
-   }
-   fclose(fp_in);
+   sprintf(report,"%s/dansguardian.html",outdirname);
 
    if((fp_in=MY_FOPEN(dansguardian_in,"r"))==NULL) {
-     fprintf(stderr, "SARG: (dansguardian_report) %s: %s\n",text[8],dansguardian_in);
-     exit(1);
+     debuga(_("(dansguardian_report) Cannot open log file %s\n"),dansguardian_in);
+     exit(EXIT_FAILURE);
    }
 
    if((fp_ou=MY_FOPEN(report,"w"))==NULL) {
-     fprintf(stderr, "SARG: (dansguardian_report) %s: %s\n",text[8],report);
-     exit(1);
+     debuga(_("(dansguardian_report) Cannot open log file %s\n"),report);
+     exit(EXIT_FAILURE);
    }
 
-   fprintf(fp_ou, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n<html>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
-   css(fp_ou);
-   fputs("</head>\n",fp_ou);
-   if(strlen(FontFace) > 0) fprintf(fp_ou,"<font face=%s>\n",FontFace);
-   fprintf(fp_ou,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
-   write_logo_image(fp_ou);
+   write_html_header(fp_ou,(IndexTree == INDEX_TREE_DATE) ? 3 : 1,_("DansGuardian"));
+   fputs("<tr><td class=\"header_c\">",fp_ou);
+   fprintf(fp_ou,_("Period: %s"),period.html);
+   fputs("</td></tr>\n",fp_ou);
+   fprintf(fp_ou,"<tr><th class=\"header_c\">%s</th></tr>\n",_("DansGuardian"));
+   close_html_header(fp_ou);
 
-   if(strcmp(IndexTree,"date") == 0)
-      show_sarg(fp_ou, "../../..");
-   else
-      show_sarg(fp_ou,"..");
-   fputs("<div align=\"center\"><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
-   fprintf(fp_ou,"<tr><th class=\"title\">%s</th></tr>\n",Title);
-
-   fprintf(fp_ou,"<tr><td class=\"header\">%s: %s</td></tr>\n",text[89],period);
-   fprintf(fp_ou,"<tr><th class=\"header3\">%s</th></tr>\n",text[128]);
-   fputs("</table></div>\n",fp_ou);
-
-   fputs("<div align=\"center\"><table cellpadding=\"1\" cellspacing=\"2\">\n",fp_ou);
-   fputs("<tr><td></td></tr>\n",fp_ou);
-   fprintf(fp_ou,"<tr><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th></tr>\n",text[98],text[111],text[110],text[91],text[129]);
+   fputs("<div class=\"report\"><table cellpadding=\"1\" cellspacing=\"2\">\n",fp_ou);
+   fprintf(fp_ou,"<tr><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th></tr>\n",_("USERID"),_("IP/NAME"),_("DATE/TIME"),_("ACCESSED SITE"),_("CAUSE"));
 
    while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
       getword_start(&gwarea,buf);
       if (getword(user,sizeof(user),&gwarea,'\t')<0 || getword(date2,sizeof(date2),&gwarea,'\t')<0 ||
-          getword(hour,sizeof(hour),&gwarea,'\t')<0 || getword(ip,sizeof(ip),&gwarea,'\t')<0 ||
-          getword(url,sizeof(url),&gwarea,'\t')<0 || getword(rule,sizeof(rule),&gwarea,'\n')<0) {
-         printf("SARG: Maybe you have a broken record or garbage in your %s file.\n",dansguardian_in);
-         exit(1);
+          getword(hour,sizeof(hour),&gwarea,'\t')<0 || getword(ip,sizeof(ip),&gwarea,'\t')<0) {
+         debuga(_("Maybe you have a broken record or garbage in your %s file\n"),dansguardian_in);
+         exit(EXIT_FAILURE);
+      }
+      if (getword_ptr(buf,&url,&gwarea,'\t')<0) {
+         debuga(_("Maybe you have a broken url in your %s file\n"),dansguardian_in);
+         exit(EXIT_FAILURE);
+      }
+      if (getword(rule,sizeof(rule),&gwarea,'\n')<0) {
+         debuga(_("Maybe you have a broken rule in your %s file\n"),dansguardian_in);
+         exit(EXIT_FAILURE);
       }
 
       if(UserIp)
@@ -131,11 +113,6 @@ void dansguardian_report(void)
          strncat(date,date2,4);
       }
 
-      if((str=(char *) strstr(user, "_")) != (char *) NULL ) {
-         if((str=(char *) strstr(str+1, "_")) != (char *) NULL )
-            fixip(user);
-      }
-
       if(Ip2Name)
          ip2name(ip,sizeof(ip));
 
@@ -154,11 +131,7 @@ void dansguardian_report(void)
             strcpy(oip,ip);
       }
 
-      get_usertab_name(user,name,sizeof(name));
-
-      if(dotinuser && strchr(name,'_')) {
-         subs(name,sizeof(name),"_",".");
-      }
+      user_find(name, sizeof(name), user);
 
      if(DansGuardianReportLimit) {
          if(strcmp(ouser2,name) == 0) {
@@ -171,17 +144,19 @@ void dansguardian_report(void)
             continue;
       }
 
-      fprintf(fp_ou,"<tr><td class=\"data2\" nospaw>%s</td><td class=\"data2\" nospaw>%s</td><td class=\"data2\" nospaw>%s-%s</td><td class=\"data2\" nospaw><a href=\"http://%s\">%s</a></td><td class=\"data2\" nospaw>%s</td></tr>\n",name,ip,date,hour,url,url,rule);
+      fprintf(fp_ou,"<tr><td class=\"data2\">%s</td><td class=\"data2\">%s</td><td class=\"data2\">%s-%s</td><td class=\"data2\"><a href=\"http://",name,ip,date,hour);
+      output_html_url(fp_ou,url);
+      fputs("\">",fp_ou);
+      output_html_string(fp_ou,url,100);
+      fprintf(fp_ou,"</a></td><td class=\"data2\">%s</td></tr>\n",rule);
    }
-
-   fputs("</table>\n",fp_ou);
-
-   show_info(fp_ou);
-
-   fputs("</body>\n</html>\n",fp_ou);
-
    fclose(fp_in);
-   fclose(fp_ou);
+
+   fputs("</table></div>\n",fp_ou);
+   if (write_html_trailer(fp_ou)<0)
+      debuga(_("Write error in file %s\n"),report);
+   if (fclose(fp_ou)==EOF)
+      debuga(_("Failed to close file %s - %s\n"),report,strerror(errno));
 
    unlink(dansguardian_in);
 
