@@ -27,6 +27,14 @@
 #include "include/conf.h"
 #include "include/defs.h"
 
+static void show_ignored_denied(FILE *fp_ou,int count)
+{
+   char ignored[80];
+
+   snprintf(ignored,sizeof(ignored),ngettext("%d more denied access not shown here&hellip;","%d more denied accesses not shown here&hellip;",count),count);
+   fprintf(fp_ou,"<tr><td class=\"data\"></td><td class=\"data\"></td><td class=\"data\"></td><td class=\"data2\"><i>%s</i></td></tr>\n",ignored);
+}
+
 void gen_denied_report(void)
 {
 
@@ -55,7 +63,7 @@ void gen_denied_report(void)
    ouser[0]='\0';
    ouser2[0]='\0';
 
-   sprintf(denied_in,"%s/sarg/denied.log",TempDir);
+   sprintf(denied_in,"%s/denied.log",tmp);
    if(!denied_count) {
       unlink(denied_in);
       return;
@@ -130,16 +138,18 @@ void gen_denied_report(void)
          if(strcmp(ouser2,uinfo->label) == 0) {
             count++;
          } else {
+            if(count>DeniedReportLimit && DeniedReportLimit>0)
+               show_ignored_denied(fp_ou,count-DeniedReportLimit);
             count=1;
             strcpy(ouser2,uinfo->label);
          }
-         if(count >= DeniedReportLimit)
+         if(count > DeniedReportLimit)
             continue;
       }
 
       fputs("<tr>",fp_ou);
       if (new_user)
-         fprintf(fp_ou,"<td class=\"data\">%s</td><td class=\"data\">%s</td>",uinfo->label,ip);
+         fprintf(fp_ou,"<td class=\"data\"><a href=\"%s/%s.html\">%s</a></td><td class=\"data\">%s</td>",uinfo->filename,uinfo->filename,uinfo->label,ip);
       else
          fputs("<td class=\"data\"></td><td class=\"data\"></td>",fp_ou);
       fprintf(fp_ou,"<td class=\"data\">%s-%s</td><td class=\"data2\">",data,hora);
@@ -157,13 +167,17 @@ void gen_denied_report(void)
    fclose(fp_in);
    longline_destroy(&line);
 
+   if(count>DeniedReportLimit && DeniedReportLimit>0)
+      show_ignored_denied(fp_ou,count-DeniedReportLimit);
+
    fputs("</table></div>\n",fp_ou);
    if (write_html_trailer(fp_ou)<0)
       debuga(_("Write error in file %s\n"),report);
    if (fclose(fp_ou)<0)
       debuga(_("Failed to close file %s - %s\n"),report,strerror(errno));
 
-   unlink(denied_in);
+   if (unlink(denied_in)==-1)
+      debuga(_("Failed to delete the file \"%s\" after processing it - %s\n"),denied_in,strerror(errno));
 
    return;
 }
