@@ -60,7 +60,7 @@ void download_report(void)
    ouser[0]='\0';
    ouser2[0]='\0';
 
-   snprintf(report_in,sizeof(report_in),"%s/sarg/download.log",TempDir);
+   snprintf(report_in,sizeof(report_in),"%s/download.log",tmp);
    if(access(report_in, R_OK) != 0)
       return;
 
