@@ -40,14 +40,15 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
    char olduser[MAX_USER_LEN], csort[MAXLEN];
    char wger[MAXLEN], top1[MAXLEN], top2[MAXLEN], top3[MAXLEN], user[MAX_USER_LEN];
    char strip1[MAXLEN], strip2[MAXLEN], strip3[MAXLEN], strip4[MAXLEN], strip5[MAXLEN], strip6[MAXLEN], strip7[MAXLEN];
-   char buf[MAXLEN];
+   char *buf;
+   char warea[MAXLEN];
    int totuser=0;
    time_t t;
    struct tm *local;
    int cstatus;
-   char warea[MAXLEN];
    struct getwordstruct gwarea;
    struct generalitemstruct item;
+   longline line;
 
    snprintf(wger,sizeof(wger),"%s/sarg-general",dirname);
    if((fp_in=fopen(wger,"r"))==NULL) {
@@ -70,8 +71,13 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
    olduser[0]='\0';
    totuser=0;
 
-   while(fgets(warea,sizeof(warea),fp_in)) {
-      ger_read(warea,&item,wger);
+   if ((line=longline_create())==NULL) {
+      debuga(_("Not enough memory to read file %s\n"),wger);
+      exit(EXIT_FAILURE);
+   }
+
+   while((buf=longline_read(fp_in,line))!=NULL) {
+      ger_read(buf,&item,wger);
       if(item.total) continue;
       if(strcmp(olduser,item.user) != 0)
       {
@@ -80,8 +86,6 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
          if (olduser[0] != '\0') {
 #if defined(__FreeBSD__)
             fprintf(fp_top2,"%s\t%qu\t%qu\t%qu\n",olduser,tnbytes,tnacc,tnelap);
-#elif defined(__alpha) || __ALPHA
-            fprintf(fp_top2,"%s\t%ld\t%ld\t%ld\n",olduser,tnbytes,tnacc,tnelap);
 #else
             fprintf(fp_top2,"%s\t%"PRIu64"\t%"PRIu64"\t%"PRIu64"\n",olduser,(uint64_t)tnbytes,(uint64_t)tnacc,(uint64_t)tnelap);
 #endif
@@ -99,12 +103,12 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
       tnacc+=item.nacc;
       tnelap+=item.nelap;
    }
+   fclose(fp_in);
+   longline_destroy(&line);
 
    if (olduser[0] != '\0') {
 #if defined(__FreeBSD__)
       fprintf(fp_top2,"%s\t%qu\t%qu\t%qu\n",olduser,tnbytes,tnacc,tnelap);
-#elif defined(__alpha) || __ALPHA
-      fprintf(fp_top2,"%s\t%ld\t%ld\t%ld\n",olduser,tnbytes,tnacc,tnelap);
 #else
       fprintf(fp_top2,"%s\t%"PRIu64"\t%"PRIu64"\t%"PRIu64"\n",olduser,(uint64_t)tnbytes,(uint64_t)tnacc,(uint64_t)tnelap);
 #endif
@@ -113,7 +117,6 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
       ttnelap+=tnelap;
    }
 
-   fclose(fp_in);
    fclose(fp_top2);
 
    sprintf(csort,"sort -n -T \"%s\" -r -k 2,2 -o \"%s\" \"%s\"", TempDir, top1, top2);
@@ -132,8 +135,6 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
    }
 #if defined(__FreeBSD__)
    fprintf(fp_top1,"TOTAL\t%qu\t%qu\t%qu\n",ttnbytes,ttnacc,ttnelap);
-#elif defined(__alpha) || __ALPHA
-   fprintf(fp_top1,"TOTAL\t%ld\t%ld\t%ld\n",ttnbytes,ttnacc,ttnelap);
 #else
    fprintf(fp_top1,"TOTAL\t%"PRIu64"\t%"PRIu64"\t%"PRIu64"\n",(uint64_t)ttnbytes,(uint64_t)ttnacc,(uint64_t)ttnelap);
 #endif
@@ -181,6 +182,7 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
 
    while(fgets(warea,sizeof(warea),fp_top1))
    {
+      fixendofline(warea);
       getword_start(&gwarea,warea);
       if (getword(user,sizeof(user),&gwarea,'\t')<0) {
          debuga(_("There is an invalid user ID in file %s\n"),top1);
@@ -194,7 +196,7 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
          debuga(_("There is an invalid number of access in file %s\n"),top1);
          exit(EXIT_FAILURE);
       }
-      if (getword_atoll(&elap,&gwarea,'\t')<0) {
+      if (getword_atoll(&elap,&gwarea,'\0')<0) {
          debuga(_("There is an invalid elapsed time in file %s\n"),top1);
          exit(EXIT_FAILURE);
       }
@@ -208,16 +210,12 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
          fputs("------- -------------------- -------- --------------- ------- ---------- ---------- -------\n",fp_top3);
 #if defined(__FreeBSD__)
          fprintf(fp_top3,"%-7s %20s %8qu %15s %8s %9s %10qu\n",_("TOTAL")," ",ttnacc,fixnum(ttnbytes,1)," ",buildtime(ttnelap),ttnelap);
-#elif defined(__alpha) || __ALPHA
-         fprintf(fp_top3,"%-7s %20s %8ld %15s %8s %9s %10ld\n",_("TOTAL")," ",ttnacc,fixnum(ttnbytes,1)," ",buildtime(ttnelap),ttnelap);
 #else
          fprintf(fp_top3,"%-7s %20s %8"PRIu64" %15s %8s %9s %10"PRIu64"\n",_("TOTAL")," ",(uint64_t)ttnacc,fixnum(ttnbytes,1)," ",buildtime(ttnelap),(uint64_t)ttnelap);
 #endif
       } else {
 #if defined(__FreeBSD__)
          fprintf(fp_top3,"%7d %20s %8lld %15s %3.2lf%% %10s %10qu %3.2lf%%\n",posicao,user,nacc,fixnum(nbytes,1),perc,buildtime(elap),elap,perc2);
-#elif defined(__alpha) || __ALPHA
-         fprintf(fp_top3,"%7d %20s %8lld %15s %3.2lf%% %10s %10ld %3.2lf%%\n",posicao,user,nacc,fixnum(nbytes,1),perc,buildtime(elap),elap,perc2);
 #else
          fprintf(fp_top3,"%7d %20s %8"PRIu64" %15s %3.2lf%% %10s %10"PRIu64" %3.2lf%%\n",posicao,user,(uint64_t)nacc,fixnum(nbytes,1),perc,buildtime(elap),(uint64_t)elap,perc2);
 #endif
@@ -238,8 +236,6 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
    strip_latin(strip1);
 #if defined(__FreeBSD__)
    fprintf(fp_top3,"%-7s %20s %8qu %15s %8s %9s %10qu\n",strip1," ",avgacc,fixnum(tnbytes,1)," ",buildtime(avgelap),avgelap);
-#elif defined(__alpha) || __ALPHA
-   fprintf(fp_top3,"%-7s %20s %8ld %15s %8s %9s %10ld\n",strip1," ",avgacc,fixnum(tnbytes,1)," ",buildtime(avgelap),avgelap);
 #else
    fprintf(fp_top3,"%-7s %20s %8"PRIu64" %15s %8s %9s %10"PRIu64"\n",strip1," ",(uint64_t)avgacc,fixnum(tnbytes,1)," ",buildtime(avgelap),(uint64_t)avgelap);
 #endif
@@ -259,23 +255,19 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
          exit(EXIT_FAILURE);
       }
 
-      while(fgets(buf,sizeof(buf),fp_top3)!=NULL)
-         fputs(buf,stdout);
+      while(fgets(warea,sizeof(warea),fp_top3)!=NULL)
+         fputs(warea,stdout);
     } else {
-      snprintf(buf,sizeof(buf),"\"%s\" -s \"SARG %s, %s\" \"%s\" <\"%s\"",MailUtility,_("Report"),asctime(local),email,top3);
-      cstatus=system(buf);
+      snprintf(warea,sizeof(warea),"%s -s \"SARG %s, %s\" \"%s\" <\"%s\"",MailUtility,_("Report"),asctime(local),email,top3);
+      cstatus=system(warea);
       if (!WIFEXITED(cstatus) || WEXITSTATUS(cstatus)) {
          debuga(_("command return status %d\n"),WEXITSTATUS(cstatus));
-         debuga(_("command: %s\n"),buf);
+         debuga(_("command: %s\n"),warea);
          exit(EXIT_FAILURE);
       }
     }
 
-   if (snprintf(warea,sizeof(warea),"%s/sarg",TempDir)>=sizeof(warea)) {
-      debuga(_("Temporary directory name too long: %s\n"),warea);
-      exit(EXIT_FAILURE);
-   }
-   unlinkdir(warea,0);
+   //unlinkdir(TempDir,0);
 
    return (0);
 }
