@@ -62,8 +62,8 @@ static void store_exclude_ip4(unsigned short int *addr,int mask)
       ip4allocated+=5;
       temp=realloc(exclude_ip4,ip4allocated*sizeof(*temp));
       if (temp==NULL) {
-         fprintf(stderr,"SARG: Not enough memory to store the exlcluded IP addresses\n");
-         exit(1);
+         debuga(_("Not enough memory to store the exlcluded IP addresses\n"));
+         exit(EXIT_FAILURE);
       }
       exclude_ip4=temp;
    }
@@ -107,8 +107,8 @@ static void store_exclude_url(char *url,int length)
       nameallocated+=5;
       temp=realloc(exclude_name,nameallocated*sizeof(*temp));
       if (temp==NULL) {
-         fprintf(stderr,"SARG: Not enough memory to store the exlcluded URL\n");
-         exit(1);
+         debuga(_("Not enough memory to store the excluded URLs\n"));
+         exit(EXIT_FAILURE);
       }
       exclude_name=temp;
    }
@@ -117,8 +117,8 @@ static void store_exclude_url(char *url,int length)
    num_exclude_name++;
    item->url=malloc(length+1);
    if (!item->url) {
-      fprintf(stderr,"SARG: Not enough memory to store the excluded URL\n");
-      exit(1);
+      debuga(_("Not enough memory to store the excluded URLs\n"));
+      exit(EXIT_FAILURE);
    }
    strncpy(item->url,url,length);
    item->url[length]='\0';
@@ -128,7 +128,6 @@ static void store_exclude_url(char *url,int length)
 
 void gethexclude(const char *hexfile, int debug)
 {
-
    FILE *fp_ex;
    char buf[255];
    int i;
@@ -139,19 +138,19 @@ void gethexclude(const char *hexfile, int debug)
    int mask, max_mask;
 
    if(access(hexfile, R_OK) != 0) {
-      debuga("Cannot open exclude_hosts file: %s - %s",hexfile,strerror(errno));
-      exit(1);
+      debuga(_("Cannot open exclude_hosts file: %s - %s\n"),hexfile,strerror(errno));
+      exit(EXIT_FAILURE);
    }
    if(debug)
-      debuga("%s: %s",text[67],hexfile);
+      debuga(_("Loading exclude host file from: %s\n"),hexfile);
 
    if ((fp_ex = fopen(hexfile, "r")) == NULL) {
-      fprintf(stderr, "SARG: (gethexclude) %s: %s - %s\n",text[45],hexfile,strerror(errno));
-      exit(1);
+      debuga(_("(gethexclude) Cannot open file %s - %s\n"),hexfile,strerror(errno));
+      exit(EXIT_FAILURE);
    }
 
    while(fgets(buf,sizeof(buf),fp_ex)!=NULL){
-      if(strchr(buf,'#') != NULL)
+      if(buf[0]=='#')
          continue;
       fixendofline(buf);
       ip_size=0x60  | 0x04;
@@ -208,8 +207,8 @@ void gethexclude(const char *hexfile, int debug)
          if (ip_size & 0x04)
             store_exclude_ip4(addr,mask);
          else {
-            fprintf(stderr,"SARG: IPv6 addresses are not supported (found in %s)\n",hexfile);
-            exit(1);
+            debuga(_("IPv6 addresses are not supported (found in %s)\n"),hexfile);
+            exit(EXIT_FAILURE);
          }
       } else {
          store_exclude_url(buf,i);
@@ -217,7 +216,6 @@ void gethexclude(const char *hexfile, int debug)
    }
 
    fclose(fp_ex);
-
    return;
 }
 
@@ -320,25 +318,31 @@ void getuexclude(const char *uexfile, int debug)
    long int nreg=0;
 
    if(debug)
-      debuga("%s: %s",text[67],uexfile);
+      debuga(_("Loading exclude file from: %s\n"),uexfile);
 
    if ((fp_ex = fopen(uexfile, "r")) == NULL) {
-      fprintf(stderr, "SARG: (gethexclude) %s: %s - %s\n",text[45],uexfile,strerror(errno));
-      exit(1);
+      debuga(_("(gethexclude) Cannot open file %s - %s\n"),uexfile,strerror(errno));
+      exit(EXIT_FAILURE);
    }
 
-   fseek(fp_ex, 0, SEEK_END);
+   if (fseek(fp_ex, 0, SEEK_END)==-1) {
+      debuga(_("Failed to move till the end of the excluded users file %s: %s\n"),uexfile,strerror(errno));
+      exit(EXIT_FAILURE);
+   }
    nreg = ftell(fp_ex);
    if (nreg<0) {
-      printf("SARG: Cannot get the size of file %s",uexfile);
-      exit(1);
+      debuga(_("Cannot get the size of file %s\n"),uexfile);
+      exit(EXIT_FAILURE);
    }
    nreg += 11;
-   fseek(fp_ex, 0, SEEK_SET);
+   if (fseek(fp_ex, 0, SEEK_SET)==-1) {
+      debuga(_("Failed to rewind the excluded users file %s: %s\n"),uexfile,strerror(errno));
+      exit(EXIT_FAILURE);
+   }
 
    if((excludeuser=(char *) malloc(nreg))==NULL){
-      fprintf(stderr, "SARG: %s (%ld):\n",text[59],nreg);
-      exit(1);
+      debuga(_("malloc error (%ld bytes required)\n"),nreg);
+      exit(EXIT_FAILURE);
    }
 
    bzero(excludeuser,nreg);
@@ -375,9 +379,9 @@ int vuexclude(const char *user)
    return(1);
 }
 
-int is_indexonly(void)
+bool is_indexonly(void)
 {
-   if (excludeuser==NULL) return(0);
+   if (excludeuser==NULL) return(false);
    return(strstr(excludeuser,"indexonly") != NULL);
 }
 
