@@ -41,6 +41,14 @@ struct param_list
    unsigned long int exclude;
 };
 
+struct sort_list
+{
+   //! The name of the value of the parameter.
+   const char *name;
+   //! The bit to set if the value is found.
+   unsigned long int value;
+};
+
 static struct param_list report_type_values[]=
 {
    {"users_sites",REPORT_TYPE_USERS_SITES,0},
@@ -148,6 +156,28 @@ static struct param_list realtime_unauth_values[]=
    {"ignore",REALTIME_UNAUTH_REC_IGNORE,~REALTIME_UNAUTH_REC_IGNORE},
 };
 
+struct sort_list topuser_sort[]=
+{
+   {"BYTES",TOPUSER_SORT_BYTES},
+   {"USER",TOPUSER_SORT_USER},
+   {"CONNECT",TOPUSER_SORT_CONNECT},
+   {"TIME",TOPUSER_SORT_TIME},
+};
+
+struct sort_list topsite_sort[]=
+{
+   {"BYTES",TOPSITE_SORT_BYTES},
+   {"CONNECT",TOPSITE_SORT_CONNECT},
+};
+
+struct sort_list user_sort[]=
+{
+   {"BYTES",USER_SORT_BYTES},
+   {"SITE",USER_SORT_SITE},
+   {"CONNECT",USER_SORT_CONNECT},
+   {"TIME",USER_SORT_TIME},
+};
+
 static int is_param(const char *param,const char *buf)
 {
    int plen;
@@ -325,6 +355,52 @@ static int getparam_list(const char *param,struct param_list *options,int noptio
    return(1);
 }
 
+static int getparam_sort(const char *param,struct sort_list *options,int noptions,char *buf,unsigned long int *value)
+{
+   int plen;
+   char *str, *order;
+   int i;
+
+   plen=strlen(param);
+   if (strncmp(buf,param,plen) != 0) return(0);
+   buf+=plen;
+   if ((unsigned char)*buf>' ') return(0);
+   while (*buf && (unsigned char)*buf<=' ') buf++;
+
+   str=buf;
+   order=NULL;
+   while (*str && (unsigned char)*str>' ') str++;
+   if (*str) {
+      *str++='\0';
+      while (*str && (unsigned char)*str<=' ') str++;
+      order=str;
+   }
+   for (i=0 ; i<noptions && strcasecmp(buf,options[i].name) ; i++);
+   if (i>=noptions) {
+      debuga(_("Unknown sort criterion \"%s\" for parameter \"%s\"\n"),buf,param);
+      exit(EXIT_FAILURE);
+   }
+   *value|=options[i].value;
+
+   if (order) {
+      str=order;
+      while (*str && (unsigned char)*str>' ') str++;
+      if (*str) {
+         *str++='\0';
+         while (*str && (unsigned char)*str<=' ') str++;
+      }
+      if (strcasecmp(order,"reverse")==0 || strcasecmp(order,"D")==0) {
+         *value|=SORT_REVERSE;
+      } else if (strcasecmp(order,"normal")!=0 && strcasecmp(order,"A")!=0) {
+         debuga(_("Unknown sort order \"%s\" for parameter \"%s\"\n"),order,param);
+         exit(EXIT_FAILURE);
+      }
+   }
+
+   buf=str;
+   return(1);
+}
+
 static void parmtest(char *buf)
 {
    char wbuf[2048];
@@ -396,6 +472,7 @@ static void parmtest(char *buf)
          debuga(_("Error: Invalid syntax in hours tag!\n"));
          exit( 1 );
       }
+      return;
    }
 
    if (is_param("weekdays",buf)) {
@@ -403,11 +480,12 @@ static void parmtest(char *buf)
          debuga(_("Error: Invalid syntax in weekdays tag!\n"));
          exit( 1 );
       }
+      return;
    }
 
-   if (getparam_2words("topuser_sort_field",buf,TopuserSortField,sizeof(TopuserSortField),TopuserSortOrder,sizeof(TopuserSortOrder))>0) return;
+   if (getparam_sort("topuser_sort_field",SET_LIST(topuser_sort),buf,&TopuserSort)>0) return;
 
-   if (getparam_2words("user_sort_field",buf,UserSortField,sizeof(UserSortField),UserSortOrder,sizeof(UserSortOrder))>0) return;
+   if (getparam_sort("user_sort_field",SET_LIST(user_sort),buf,&UserSort)>0) return;
 
    if (is_param("access_log",buf)>0) {
       if (AccessLogFromCmdLine==0) {
@@ -482,7 +560,7 @@ static void parmtest(char *buf)
 
    if (getparam_string("index_sort_order",buf,IndexSortOrder,sizeof(IndexSortOrder))>0) return;
 
-   if (getparam_2words("topsites_sort_order",buf,TopsitesSortField,sizeof(TopsitesSortField),TopsitesSortType,sizeof(TopsitesSortType))>0) return;
+   if (getparam_sort("topsites_sort_order",SET_LIST(topsite_sort),buf,&TopsitesSort)>0) return;
 
    if (getparam_bool("long_url",buf,&LongUrl)>0) return;
 
