@@ -43,18 +43,20 @@ void htmlrel(void)
    char arqin[MAXLEN], arqou[MAXLEN], arqper[MAXLEN], arqip[MAXLEN];
    char *url, tmsg[50], csort[MAXLEN];
    char user[MAXLEN], duser[MAXLEN];
-   char userhora[9], userdia[9];
    char user_ip[MAXLEN], olduserip[MAXLEN], tmp2[MAXLEN], tmp3[MAXLEN];
    char denied_report[255];
    char *str;
    char warea[MAXLEN];
    char totuser[8];
    char tmp6[MAXLEN];
+   char *user_url;
    long long int tnacc=0, ttnacc=0, unacc=0;
    double perc=0, perc2=0, ouperc=0, inperc=0;
    int count;
    int cstatus;
    const char txtext[]=".txt";
+   const char *sort_field;
+   const char *sort_order;
    int dlen;
    char siteind[MAX_TRUNCATED_URL];
    struct getwordstruct gwarea;
@@ -64,10 +66,10 @@ void htmlrel(void)
 
    if((ReportType & REPORT_TYPE_USERS_SITES) == 0) return;
 
-   strcpy(tmp2,TempDir);
+   strcpy(tmp2,tmp);
    strcat(tmp2,"/sargtmp.unsort");
 
-   strcpy(tmp3,TempDir);
+   strcpy(tmp3,tmp);
    strcat(tmp3,"/sargtmp.log");
 
    snprintf(arqper,sizeof(arqper),"%s/sarg-general",outdirname);
@@ -108,6 +110,8 @@ void htmlrel(void)
 
    greport_prepare();
 
+   sort_labels(&sort_field,&sort_order);
+
    if ((dirp = opendir(tmp)) == NULL) {
       debuga(_("Failed to open directory %s - %s\n"),tmp,strerror(errno));
       exit(EXIT_FAILURE);
@@ -224,7 +228,9 @@ void htmlrel(void)
       write_html_header(fp_ou,(IndexTree == INDEX_TREE_DATE) ? 4 : 2,_("User report"));
       fprintf(fp_ou,"<tr><td class=\"header_c\">%s:&nbsp;%s</td></tr>\n",_("Period"),period.html);
       fprintf(fp_ou,"<tr><td class=\"header_c\">%s:&nbsp;%s</td></tr>\n",_("User"),uinfo->label);
-      fprintf(fp_ou,"<tr><td class=\"header_c\">%s:&nbsp;%s, %s</td></tr>\n",_("Sort"),UserSortField,UserSortOrder);
+      fputs("<tr><td class=\"header_c\">",fp_ou);
+      fprintf(fp_ou,_("Sort:&nbsp;%s, %s"),sort_field,sort_order);
+      fputs("</td></tr>\n",fp_ou);
       fprintf(fp_ou,"<tr><th class=\"header_c\">%s</th></tr>\n",_("User report"));
       close_html_header(fp_ou);
 
@@ -369,15 +375,40 @@ void htmlrel(void)
                exit(EXIT_FAILURE);
             }
             while((buf=longline_read(fp_ip,line1))!=NULL) {
-               if(strstr(buf,url) != 0)
-                  fputs(buf,fp_ip2);
+               getword_start(&gwarea,buf);
+               if (getword(user_ip,sizeof(user_ip),&gwarea,'\t')<0) {
+                  debuga(_("Maybe you have a broken user IP in your %s file\n"),tmp3);
+                  exit(EXIT_FAILURE);
+               }
+               if (getword_ptr(buf,&user_url,&gwarea,'\t')<0) {
+                  debuga(_("Maybe you have a broken url in your %s file\n"),tmp3);
+                  exit(EXIT_FAILURE);
+               }
+               if (strncmp(user_url,url,strlen(url))!=0) continue;
+               if (getword_skip(15,&gwarea,'\t')<0) {
+                  debuga(_("Maybe you have a broken day in your %s file\n"),tmp3);
+                  exit(EXIT_FAILURE);
+               }
+               if (getword_skip(15,&gwarea,'\t')<0) {
+                  debuga(_("Maybe you have a broken time in your %s file\n"),tmp3);
+                  exit(EXIT_FAILURE);
+               }
+               if (getword_atoll(&userbytes,&gwarea,'\t')<0) {
+                  debuga(_("Maybe you have a broken size in your %s file\n"),tmp3);
+                  exit(EXIT_FAILURE);
+               }
+               if (getword_atoll(&userelap,&gwarea,'\0')<0) {
+                  debuga(_("Maybe you have a broken elapsed time in your %s file\n"),tmp3);
+                  exit(EXIT_FAILURE);
+               }
+               fprintf(fp_ip2,"%s\t%"PRIu64"\t%"PRIu64"\n",user_ip,(uint64_t)userbytes,(uint64_t)userelap);
             }
             longline_destroy(&line1);
 
             fclose(fp_ip);
             fclose(fp_ip2);
 
-            sprintf(csort,"sort -n -T \"%s\" -k 1,1 -k 5,5 -o \"%s\" \"%s\"",TempDir,tmp3,tmp2);
+            sprintf(csort,"sort -n -T \"%s\" -k 1,1 -k 2,2 -o \"%s\" \"%s\"",tmp,tmp3,tmp2);
             cstatus=system(csort);
             if (!WIFEXITED(cstatus) || WEXITSTATUS(cstatus)) {
                debuga(_("sort command return status %d\n"),WEXITSTATUS(cstatus));
@@ -402,33 +433,31 @@ void htmlrel(void)
                   debuga(_("Maybe you have a broken user IP in your %s file\n"),tmp3);
                   exit(EXIT_FAILURE);
                }
-               if (getword_ptr(NULL,NULL,&gwarea,'\t')<0) {
-                  debuga(_("Maybe you have a broken url in your %s file\n"),tmp3);
-                  exit(EXIT_FAILURE);
-               }
-               if (getword(userdia,sizeof(userdia),&gwarea,'\t')<0) {
-                  debuga(_("Maybe you have a broken day in your %s file\n"),tmp3);
-                  exit(EXIT_FAILURE);
-               }
-               if (getword(userhora,sizeof(userhora),&gwarea,'\t')<0) {
-                  debuga(_("Maybe you have a broken time in your %s file\n"),tmp3);
-                  exit(EXIT_FAILURE);
-               }
                if (getword_atoll(&userbytes,&gwarea,'\t')<0) {
                   debuga(_("Maybe you have a broken size in your %s file\n"),tmp3);
                   exit(EXIT_FAILURE);
                }
-               if (getword_atoll(&userelap,&gwarea,'\t')<0) {
+               if (getword_atoll(&userelap,&gwarea,'\0')<0) {
                   debuga(_("Maybe you have a broken elapsed time in your %s file\n"),tmp3);
                   exit(EXIT_FAILURE);
                }
                if(strcmp(user_ip,olduserip) != 0) {
-                  sprintf(wwork1,"%s",fixnum(unbytes,1));
-                  /*
-                  This complicated printf is due to Microsoft's inability to comply with any standard. Msvcrt is unable
-                  to print a long long int unless it is exactly 64-bits long.
-                  */
-                  fprintf(fp_ou,"<tr><td></td><td class=\"data\">%s</td><td></td><td class=\"data\">%s</td><td></td><td></td><td></td><td class=\"data\">%s</td><td class=\"data\">%"PRIu64"</td></tr>\n",olduserip,wwork1,buildtime(unelap),(uint64_t)unelap);
+                  if (olduserip[0]!='\0') {
+                     fprintf(fp_ou,"<tr><td></td><td class=\"data\">%s</td>",olduserip);
+                     if((UserReportFields & USERREPORTFIELDS_CONNECT) != 0)
+                        fputs("<td></td>",fp_ou);
+                     if((UserReportFields & USERREPORTFIELDS_BYTES) != 0)
+                        fprintf(fp_ou,"<td class=\"data\">%s</td>",fixnum(unbytes,1));
+                     if((UserReportFields & USERREPORTFIELDS_SETYB) != 0)
+                        fputs("<td></td>",fp_ou);
+                     if((UserReportFields & USERREPORTFIELDS_IN_CACHE_OUT) != 0)
+                        fputs("</td><td></td><td></td>",fp_ou);
+                     if((UserReportFields & USERREPORTFIELDS_USED_TIME) != 0)
+                        fprintf(fp_ou,"<td class=\"data\">%s</td>",buildtime(unelap));
+                     if((UserReportFields & USERREPORTFIELDS_MILISEC) != 0)
+                        fprintf(fp_ou,"<td class=\"data\">%s</td>",fixnum2(unelap,1));
+                     fputs("</tr>\n",fp_ou);
+                  }
 
                   strcpy(olduserip,user_ip);
                   unacc=0;
@@ -436,8 +465,8 @@ void htmlrel(void)
                   unelap=0;
                }
 
-               unbytes=unbytes+userbytes;
-               unelap=unelap+userelap;
+               unbytes+=userbytes;
+               unelap+=userelap;
             }
 
             fclose(fp_ip);
@@ -446,12 +475,22 @@ void htmlrel(void)
             unlink(tmp2);
             unlink(tmp3);
 
-            sprintf(wwork1,"%s",fixnum(unbytes,1));
-            /*
-            This complicated printf is due to Microsoft's inability to comply with any standard. Msvcrt is unable
-            to print a long long int unless it is exactly 64-bits long.
-            */
-            fprintf(fp_ou,"<tr><td></td><td class=\"data\">%s</td><td></td><td class=\"data\">%s</td><td></td><td></td><td></td><td class=\"data\">%s</td><td class=\"data\">%"PRIu64"</td></tr>\n",olduserip,wwork1,buildtime(unelap),(uint64_t)unelap);
+            if (olduserip[0]!='\0') {
+               fprintf(fp_ou,"<tr><td></td><td class=\"data\">%s</td>",olduserip);
+               if((UserReportFields & USERREPORTFIELDS_CONNECT) != 0)
+                  fputs("<td></td>",fp_ou);
+               if((UserReportFields & USERREPORTFIELDS_BYTES) != 0)
+                  fprintf(fp_ou,"<td class=\"data\">%s</td>",fixnum(unbytes,1));
+               if((UserReportFields & USERREPORTFIELDS_SETYB) != 0)
+                  fputs("<td></td>",fp_ou);
+               if((UserReportFields & USERREPORTFIELDS_IN_CACHE_OUT) != 0)
+                  fputs("</td><td></td><td></td>",fp_ou);
+               if((UserReportFields & USERREPORTFIELDS_USED_TIME) != 0)
+                  fprintf(fp_ou,"<td class=\"data\">%s</td>",buildtime(unelap));
+               if((UserReportFields & USERREPORTFIELDS_MILISEC) != 0)
+                  fprintf(fp_ou,"<td class=\"data\">%s</td>",fixnum2(unelap,1));
+               fputs("</tr>\n",fp_ou);
+            }
          }
 
          unacc=0;
