@@ -241,8 +241,26 @@ int mkstemps(char *template, int suffixlen);
 #define DATETIME_ELAP 0x0001UL
 #define DATETIME_BYTE 0x0002UL
 
-#define REALTIME_UNAUTH_REC_SHOW 0x0001UL
-#define REALTIME_UNAUTH_REC_IGNORE 0x0001UL
+#define REALTIME_UNAUTH_REC_SHOW   0x0001UL
+#define REALTIME_UNAUTH_REC_IGNORE 0x0002UL
+
+#define SORT_REVERSE 0x0001
+
+#define TOPUSER_SORT_REVERSE SORT_REVERSE
+#define TOPUSER_SORT_BYTES   0x0002UL
+#define TOPUSER_SORT_USER    0x0004UL
+#define TOPUSER_SORT_CONNECT 0x0008UL
+#define TOPUSER_SORT_TIME    0x0010UL
+
+#define TOPSITE_SORT_REVERSE SORT_REVERSE
+#define TOPSITE_SORT_BYTES   0x0002UL
+#define TOPSITE_SORT_CONNECT 0x0004UL
+
+#define USER_SORT_REVERSE SORT_REVERSE
+#define USER_SORT_BYTES   0x0002UL
+#define USER_SORT_SITE    0x0004UL
+#define USER_SORT_CONNECT 0x0008UL
+#define USER_SORT_TIME    0x0010UL
 
 struct periodstruct
 {
@@ -278,8 +296,7 @@ char MailUtility[PATH_MAX];
 int TopSitesNum;
 int TopUsersNum;
 char ExcludeCodes[256];
-char TopsitesSortField[15];
-char TopsitesSortType[20];
+unsigned long int TopsitesSort;
 unsigned long int ReportType;
 char UserTabFile[255];
 char warea[MAXLEN];
@@ -308,10 +325,8 @@ char PasswdFile[MAXLEN];
 char TempDir[MAXLEN];
 char OutputDir[MAXLEN];
 char OutputEmail[MAXLEN];
-char TopuserSortField[30];
-char UserSortField[30];
-char TopuserSortOrder[10];
-char UserSortOrder[10];
+unsigned long int TopuserSort;
+unsigned long int UserSort;
 char UserAgentLog[255];
 char module[255];
 char ExcludeHosts[255];
