@@ -26,17 +26,50 @@
 
 #include "include/conf.h"
 #include "include/defs.h"
+#ifdef HAVE_WS2TCPIP_H
+#include <ws2tcpip.h> //define getnameinfo on windows 
+#endif
 
 void ip2name(char *ip,int ip_len)
 {
-   u_long addr;
+#ifdef HAVE_GETNAMEINFO
+   struct sockaddr_storage sa;
+   char host[NI_MAXHOST];
+   int n1,n2,n3,n4,next=0;
+   int error;
+
+   memset(&sa,0,sizeof(sa));
+   if (sscanf(ip,"%d.%d.%d.%d%n",&n1,&n2,&n3,&n4,&next)==4 && ip[next]=='\0') {
+      struct sockaddr_in *s4=(struct sockaddr_in *)&sa;
+      if (inet_pton(AF_INET,ip,&s4->sin_addr)!=1) return;
+      sa.ss_family=AF_INET;
+   } else {
+      struct sockaddr_in6 *s6=(struct sockaddr_in6 *)&sa;
+      if (inet_pton(AF_INET6,ip,&s6->sin6_addr)!=1) return;
+      sa.ss_family=AF_INET6;
+   }
+   error=getnameinfo((struct sockaddr *)&sa,sizeof(sa),host,sizeof(host),NULL,0,0);
+   if (error==0)
+   {
+      strncpy(ip,host,ip_len-1);
+      ip[ip_len-1]='\0';
+   } else {
+      debuga(_("IP to name resolution (getnameinfo) on IP address %s failed with error %d - %s\n"),ip,error,gai_strerror(error));
+   }
+#else
+   struct in_addr addr;
    struct hostent *hp;
    char **p;
 
-   if ((int)(addr = inet_addr(ip)) == -1)
+#ifdef HAVE_INET_ATON
+   if (inet_aton(ip,&addr) == 0)
       return;
+#else
+   addr.s_addr=inet_addr(ip);
+   if (addr.s_addr==-1) return;
+#endif
 
-   hp = gethostbyaddr((char *)&addr, sizeof (addr), AF_INET);
+   hp = gethostbyaddr((void *)&addr, sizeof (addr), AF_INET);
    if (hp == NULL)
       return;
 
@@ -47,7 +80,7 @@ void ip2name(char *ip,int ip_len)
       strncpy(ip,hp->h_name,ip_len-1);
       ip[ip_len-1]=0;
    }
-
+#endif
    return;
 }
 
@@ -74,7 +107,7 @@ void name2ip(char *name)
    if (getword(n4,sizeof(n4),&gwarea,'.')<0 || getword(n3,sizeof(n3),&gwarea,'.')<0 ||
          getword(n2,sizeof(n2),&gwarea,'.')<0 || getword(n1,sizeof(n1),&gwarea,0)<0) {
       printf("SARG: Maybe you have a broken record or garbage in your %s ip address.\n",gwarea.beginning);
-      exit(1);
+      exit(EXIT_FAILURE);
    }
    sprintf(name,"%s.%s.%s.%s",n1,n2,n3,n4);
 
