@@ -92,7 +92,6 @@ int main(int argc,char *argv[])
    char ano[30];
    char hora[30];
    char wtemp[MAXLEN];
-   char wtemp2[255];
    char date[255];
    char arq[255];
    char arq_log[255];
@@ -105,7 +104,6 @@ int main(int argc,char *argv[])
    char tbuf2[128];
    char zip[20];
    char *str;
-   char tmp2[MAXLEN];
    char tmp3[MAXLEN];
    char denied_unsort[MAXLEN];
    char denied_sort[MAXLEN];
@@ -235,12 +233,9 @@ int main(int argc,char *argv[])
    TopSitesNum=100;
    TopUsersNum=0;
    UserIp=0;
-   strcpy(TopuserSortField,"BYTES");
-   strcpy(UserSortField,"BYTES");
-   strcpy(TopuserSortOrder,"reverse");
-   strcpy(UserSortOrder,"reverse");
-   strcpy(TopsitesSortField,"CONNECT");
-   strcpy(TopsitesSortType,"D");
+   TopuserSort=TOPUSER_SORT_BYTES | TOPUSER_SORT_REVERSE;
+   UserSort=USER_SORT_BYTES | USER_SORT_REVERSE;
+   TopsitesSort=TOPSITE_SORT_CONNECT | TOPSITE_SORT_REVERSE;
    LongUrl=0;
    strcpy(FontFace,"Verdana,Tahoma,Arial");
    datetimeby=DATETIME_BYTE;
@@ -293,7 +288,7 @@ int main(int argc,char *argv[])
    LDAPBindDN[0]='\0';
    LDAPBindPW[0]='\0';
    LDAPBaseSearch[0]='\0';
-   strcpy(LDAPFilterSearch, "uid=%s");
+   strcpy(LDAPFilterSearch, "(uid=%s)");
    strcpy(LDAPTargetAttr, "cn");
 
    dia[0]='\0';
@@ -301,10 +296,8 @@ int main(int argc,char *argv[])
    ano[0]='\0';
    hora[0]='\0';
    tmp[0]='\0';
-   tmp2[0]='\0';
    tmp3[0]='\0';
    wtemp[0]='\0';
-   wtemp2[0]='\0';
    us[0]='\0';
    date[0]='\0';
    df[0]='\0';
@@ -611,6 +604,16 @@ int main(int argc,char *argv[])
 
    if(tmp[0] == '\0') strcpy(tmp,TempDir);
    else strcpy(TempDir,tmp);
+   /*
+   For historical reasons, the temporary directory is the subdirectory "sarg" of the path
+   provided by the user.
+   */
+   strcat(tmp,"/sarg");
+
+   if (tmp[0]!='\0' && strncmp(outdir,tmp,strlen(tmp))==0) {
+      debuga(_("The output directory \"%s\" must be outside of the temporary directory \"%s\"\n"),outdir,tmp);
+      exit(EXIT_FAILURE);
+   }
 
    if(df[0] == '\0') strcpy(df,DateFormat);
    else strcpy(DateFormat,df);
@@ -624,29 +627,19 @@ int main(int argc,char *argv[])
 
    if(email[0] == '\0' && OutputEmail[0] != '\0') strcpy(email,OutputEmail);
 
-   strcpy(tmp2,tmp);
-
    if(email[0] != '\0') {
-      snprintf(wtemp2,sizeof(wtemp2),"%s/sarg",tmp2);
-      my_mkdir(wtemp2);
-      strcat(tmp2,"/sarg");
-      strcpy(outdir,tmp2);
+      my_mkdir(tmp);
+      strcpy(outdir,tmp);
       strcat(outdir,"/");
    }
 
-   strcat(tmp2,"/sarg.log");
-
-   sprintf(tmp3,"%s/sarg",tmp);
-   if(access(tmp3, R_OK) == 0) {
-      unlinkdir(tmp3,1);
+   if(access(tmp, R_OK) == 0) {
+      unlinkdir(tmp,1);
    }
-   my_mkdir(tmp3);
-   strcpy(denied_unsort,tmp3);
-   strcpy(denied_sort,tmp3);
-   strcpy(authfail_unsort,tmp3);
-   strcat(denied_unsort,"/denied.log.unsort");
-   strcat(denied_sort,"/denied.log");
-   strcat(authfail_unsort,"/authfail.log.unsort");
+   my_mkdir(tmp);
+   snprintf(denied_unsort,sizeof(denied_unsort),"%s/denied.log.unsort",tmp);
+   snprintf(denied_sort,sizeof(denied_sort),"%s/denied.log",tmp);
+   snprintf(authfail_unsort,sizeof(authfail_unsort),"%s/authfail.log.unsort",tmp);
 
    if(debug) {
       debuga(_("Parameters:\n"));
@@ -713,6 +706,10 @@ int main(int argc,char *argv[])
    if(debug)
       debuga(_("sarg version: %s\n"),VERSION);
 
+#ifdef ENABLE_DOUBLE_CHECK_DATA
+   debuga(_("Sarg compiled to report warnings if the output is inconsistent\n"));
+#endif
+
    maxopenfiles=MAX_OPEN_USER_FILES;
 #ifdef HAVE_RLIM_T
    if (Ulimit[0] != '\0') {
@@ -755,7 +752,7 @@ int main(int argc,char *argv[])
       exit(EXIT_FAILURE);
    }
 
-   snprintf(sz_Download_Unsort,sizeof(sz_Download_Unsort),"%s/sarg/download.unsort", tmp);
+   snprintf(sz_Download_Unsort,sizeof(sz_Download_Unsort),"%s/download.unsort", tmp);
 
    if(DataFile[0]=='\0') {
       if((ReportType & REPORT_TYPE_DENIED) != 0) {
@@ -872,9 +869,9 @@ int main(int argc,char *argv[])
          }
 
          recs2++;
-         if( ShowReadStatistics && !from_stdin && --OutputNonZero<=0) {
+         if( ShowReadStatistics && !from_stdin && !from_pipe && --OutputNonZero<=0) {
            double perc = recs2 * 100. / recs1 ;
-           printf(_("SARG: Records in file: %lu, reading: %3.2lf%%"),recs1,perc);
+           printf(_("SARG: Records in file: %lu, reading: %3.2lf%%"),recs2,perc);
            putchar('\r');
            fflush (stdout);
            OutputNonZero = REPORT_EVERY_X_LINES ;
@@ -1458,8 +1455,8 @@ int main(int argc,char *argv[])
                   }
                }
             }
-            if (snprintf (tmp3, sizeof(tmp3), "%s/sarg/%s.unsort", tmp, ufile->user->filename)>=sizeof(tmp3)) {
-               debuga(_("Temporary user file name too long: %s/sarg/%s.unsort\n"), tmp, ufile->user->filename);
+            if (snprintf (tmp3, sizeof(tmp3), "%s/%s.unsort", tmp, ufile->user->filename)>=sizeof(tmp3)) {
+               debuga(_("Temporary user file name too long: %s/%s.unsort\n"), tmp, ufile->user->filename);
                exit(EXIT_FAILURE);
             }
             if ((ufile->file = MY_FOPEN (tmp3, "a")) == NULL) {
@@ -1471,7 +1468,7 @@ int main(int argc,char *argv[])
          /*if ( strcmp ( user , sz_Last_User ) != 0 ) {
             if ( fp_Write_User )
                fclose( fp_Write_User ) ;
-            sprintf (tmp3, "%s/sarg/%s.unsort", tmp, user);
+            sprintf (tmp3, "%s/%s.unsort", tmp, user);
 
             if ((fp_Write_User = MY_FOPEN (tmp3, "a")) == NULL) {
                fprintf (stderr, "%s: (log) %s: %s - %s\n", argv[0], _("Cannot open temporary file"), tmp3, strerror(errno));
@@ -1494,7 +1491,7 @@ int main(int argc,char *argv[])
 
             if ( ! fp_Download_Unsort ) {
                if ((fp_Download_Unsort = MY_FOPEN ( sz_Download_Unsort, "a")) == NULL) {
-                  debuga(_("(log) Cannot open temporary file: %s - %s\n"),tmp3, strerror(errno));
+                  debuga(_("(log) Cannot open temporary file: %s - %s\n"),sz_Download_Unsort, strerror(errno));
                   exit (1);
                }
             }
@@ -1540,10 +1537,11 @@ int main(int argc,char *argv[])
       if (!from_stdin) {
          if (from_pipe)
             pclose(fp_in);
-         else
+         else {
             fclose(fp_in);
-         if( ShowReadStatistics )
-            printf(_("SARG: Records in file: %lu, reading: %3.2f%%\n"),recs1, (float) 100 );
+            if( ShowReadStatistics )
+               printf(_("SARG: Records in file: %lu, reading: %3.2f%%\n"),recs1, (float) 100 );
+         }
       }
    }
 
@@ -1670,7 +1668,6 @@ int main(int argc,char *argv[])
    else
       gerarel();
 
-   unlink(tmp2);
    if((ReportType & REPORT_TYPE_DENIED) != 0)
       unlink(denied_sort);
 
