@@ -70,6 +70,8 @@ void gerarel(void)
    DIR *dirp;
    struct dirent *direntp;
    const char logext[]=".log";
+   const char *sort_field;
+   const char *sort_order;
    int dlen;
    int url_len;
    int ourl_size=0;
@@ -101,7 +103,6 @@ void gerarel(void)
    }
 
    puinfo=NULL;
-   strncat(tmp,"/sarg",5);
    fp_tt=NULL;
 
    if ((dirp = opendir(tmp)) == NULL) {
@@ -148,6 +149,7 @@ void gerarel(void)
 
       maketmp(user,tmp,debug,indexonly);
       maketmp_hour(user,tmp,indexonly);
+      sort_labels(&sort_field,&sort_order);
 
       ttopen=0;
       oldurltt=NULL;
@@ -279,7 +281,9 @@ void gerarel(void)
                write_html_header(fp_tt,(IndexTree == INDEX_TREE_DATE) ? 4 : 2,_("Site access report"));
                fprintf(fp_tt,"<tr><td class=\"header_c\">%s:&nbsp;%s</td></tr>\n",_("Period"),period.html);
                fprintf(fp_tt,"<tr><td class=\"header_c\">%s:&nbsp;%s</td></tr>\n",_("User"),uinfo->label);
-               fprintf(fp_tt,"<tr><td class=\"header_c\">%s:&nbsp;%s, %s</td></tr>\n",_("Sort"),UserSortField,UserSortOrder);
+               fputs("<tr><td class=\"header_c\">",fp_tt);
+               fprintf(fp_tt,_("Sort:&nbsp;%s, %s"),sort_field,sort_order);
+               fputs("</td></tr>\n",fp_tt);
                fprintf(fp_tt,"<tr><th class=\"header_c\">%s</th></tr>\n",_("User"));
                close_html_header(fp_tt);
 
@@ -391,7 +395,7 @@ void gerarel(void)
 
       if(SuccessfulMsg) debuga(_("Successful report generated on %s\n"),outdirname);
     } else {
-      geramail(outdirname, debug, outdir, email, TempDir);
+      geramail(outdirname, debug, outdir, email, tmp);
 
       if((strcmp(email,"stdout") != 0) && SuccessfulMsg)
          debuga(_("Successful report generated and sent to %s\n"),email);
