@@ -40,29 +40,29 @@ void tmpsort(void)
    const char *field1="2,2";
    const char *field2="1,1";
    const char *field3="3,3";
-   const char *order="-r";
+   const char *order;
 
    if(indexonly) return;
    if((ReportType & REPORT_TYPE_USERS_SITES) == 0) return;
 
-   strup(UserSortField);
-   if(strcmp(UserSortField,"CONNECT") == 0) {
+   if((UserSort & USER_SORT_CONNECT) != 0) {
       field1="1,1";
       field2="2,2";
       field3="3,3";
-   } else if(strcmp(UserSortField,"SITE") == 0) {
+   } else if((UserSort & USER_SORT_SITE) != 0) {
       field1="3,3";
       field2="2,2";
       field3="1,1";
-   } else if(strcmp(UserSortField,"TIME") == 0) {
+   } else if((UserSort & USER_SORT_TIME) != 0) {
       field1="5,5";
       field2="2,2";
       field3="1,1";
    }
 
-   strlow(UserSortOrder);
-   if(strcmp(UserSortOrder,"normal") == 0)
+   if((UserSort & USER_SORT_REVERSE) == 0)
       order="";
+   else
+      order="-r";
 
    if ((dirp = opendir(tmp)) == NULL) {
       debuga(_("Failed to open directory %s - %s\n"),tmp,strerror(errno));
@@ -93,7 +93,7 @@ void tmpsort(void)
       }
 
       strcat(arqou,".txt");
-      sprintf(csort,"sort -n -T \"%s\" %s -k %s -k %s -k %s -o \"%s\" \"%s\"",TempDir,order,field1,field2,field3,arqou,arqin);
+      sprintf(csort,"sort -n -T \"%s\" %s -k %s -k %s -k %s -o \"%s\" \"%s\"",tmp,order,field1,field2,field3,arqou,arqin);
       cstatus=system(csort);
       if (!WIFEXITED(cstatus) || WEXITSTATUS(cstatus)) {
          debuga(_("sort command return status %d\n"),WEXITSTATUS(cstatus));
@@ -113,7 +113,6 @@ void sort_users_log(const char *tmp, int debug)
    DIR *dirp;
    struct dirent *direntp;
    char csort[MAXLEN];
-   char wtmp[MAXLEN];
    char user[MAXLEN];
    char wdname[MAXLEN];
    int cstatus;
@@ -125,10 +124,8 @@ void sort_users_log(const char *tmp, int debug)
       debuga(_("pre-sorting files\n"));
    }
 
-   snprintf(wtmp,sizeof(wtmp),"%s/sarg",tmp);
-
-   if ((dirp = opendir(wtmp)) == NULL) {
-      debuga(_("Failed to open directory %s - %s\n"),wtmp,strerror(errno));
+   if ((dirp = opendir(tmp)) == NULL) {
+      debuga(_("Failed to open directory %s - %s\n"),tmp,strerror(errno));
       exit(EXIT_FAILURE);
    }
    while ( (direntp = readdir( dirp )) != NULL ){
@@ -149,10 +146,10 @@ void sort_users_log(const char *tmp, int debug)
 
       if(strcmp(direntp->d_name,"download.unsort") == 0)
          clen=snprintf(csort,sizeof(csort),"sort -T \"%s\" -k 3,3 -k 1,1 -k 2,2 -k 5,5 -o \"%s/%s.log\" \"%s/%s.unsort\"",
-              tmp, wtmp, user, wtmp, user);
+              tmp, tmp, user, tmp, user);
       else
          clen=snprintf(csort,sizeof(csort),"sort -T \"%s\" -k 4,4 -k 1,1 -k 2,2 -o \"%s/%s.log\" \"%s/%s.unsort\"",
-              tmp, wtmp, user, wtmp, user);
+              tmp, tmp, user, tmp, user);
       if (clen>=sizeof(csort)) {
          debuga(_("user name too long to sort %s\n"),csort);
          exit(EXIT_FAILURE);
@@ -163,8 +160,8 @@ void sort_users_log(const char *tmp, int debug)
          debuga(_("sort command: %s\n"),csort);
          exit(EXIT_FAILURE);
       }
-      if (snprintf(wdname,sizeof(wdname),"%s/%s.unsort",wtmp,user)>=sizeof(wdname)) {
-         debuga(_("user name too long for %s/%s.unsort\n"),wtmp,user);
+      if (snprintf(wdname,sizeof(wdname),"%s/%s.unsort",tmp,user)>=sizeof(wdname)) {
+         debuga(_("user name too long for %s/%s.unsort\n"),tmp,user);
          exit(EXIT_FAILURE);
       }
       unlink(wdname);
@@ -173,3 +170,21 @@ void sort_users_log(const char *tmp, int debug)
 
    return;
 }
+
+void sort_labels(const char **label,const char **order)
+{
+   if((UserSort & USER_SORT_CONNECT) != 0) {
+      *label=_("connect");
+   } else if((UserSort & USER_SORT_SITE) != 0) {
+      *label=_("site");
+   } else if((UserSort & USER_SORT_TIME) != 0) {
+      *label=_("time");
+   } else {
+      *label=_("bytes");
+   }
+
+   if((UserSort & USER_SORT_REVERSE) == 0)
+      *order=_("normal");
+   else
+      *order=_("reverse");
+}
