@@ -153,21 +153,16 @@ void topsites(void)
 
    fclose(fp_ou);
 
-   strlow(TopsitesSortField);
-   strlow(TopsitesSortType);
-
-   if(strcmp(TopsitesSortField,"connect") == 0)
+   if((TopsitesSort & TOPSITE_SORT_CONNECT) != 0) {
       sortf="-k 1,1 -k 2,2";
-   else if(strcmp(TopsitesSortField,"bytes") == 0)
+   } else {
       sortf="-k 2,2 -k 1,1";
-   else
-      sortf="";
-   if(strcmp(TopsitesSortType,"a") == 0)
-      sortt="";
-   else if(strcmp(TopsitesSortType,"d") == 0)
+   }
+   if((TopsitesSort & TOPSITE_SORT_REVERSE) != 0) {
       sortt="-r";
-   else
+   } else {
       sortt="";
+   }
 
    sprintf(csort,"sort %s -n %s -o \"%s\" \"%s\"",sortt,sortf,sites,general3);
    cstatus=system(csort);
