@@ -46,7 +46,9 @@ void topuser(void)
    char user[MAX_USER_LEN], tusr[MAXLEN];
    char ipantes[MAXLEN], nameantes[MAXLEN];
    const char *sfield="-n -k 2,2";
-   const char *order="-r";
+   const char *order;
+   const char *sort_field;
+   const char *sort_order;
    char title[80];
    char *warea;
    int  totuser=0;
@@ -132,23 +134,29 @@ void topuser(void)
    }
    fclose(fp_top2);
 
-   strup(TopuserSortField);
-   strlow(TopuserSortOrder);
-
-   if(strcmp(TopuserSortField,"USER") == 0)
+   if((TopuserSort & TOPUSER_SORT_USER) != 0) {
       sfield="-k 1,1";
-
-   if(strcmp(TopuserSortField,"CONNECT") == 0)
+      sort_field=_("user");
+   } else if((TopuserSort & TOPUSER_SORT_CONNECT) != 0) {
       sfield="-n -k 3,3";
-
-   if(strcmp(TopuserSortField,"TIME") == 0)
+      sort_field=_("connect");
+   } else if((TopuserSort & TOPUSER_SORT_TIME) != 0) {
       sfield="-n -k 4,4";
+      sort_field=_("time");
+   } else {
+      sort_field=_("bytes");
+   }
 
-   if(strcmp(TopuserSortOrder,"normal") == 0)
+   if((TopuserSort & TOPUSER_SORT_REVERSE) == 0) {
       order="";
+      sort_order=_("normal");
+   } else {
+      order="-r";
+      sort_order=_("reverse");
+   }
 
    snprintf(top1,sizeof(top1),"%s/top",outdirname);
-   sprintf(csort,"sort -T \"%s\" %s %s -o \"%s\" \"%s\"", TempDir, order, sfield, top1, top2);
+   sprintf(csort,"sort -T \"%s\" %s %s -o \"%s\" \"%s\"", tmp, order, sfield, top1, top2);
    cstatus=system(csort);
    if (!WIFEXITED(cstatus) || WEXITSTATUS(cstatus)) {
       debuga(_("sort command return status %d\n"),WEXITSTATUS(cstatus));
@@ -174,7 +182,9 @@ void topuser(void)
    fputs("<tr><td class=\"header_c\">",fp_top3);
    fprintf(fp_top3,_("Period: %s"),period.html);
    fputs("</td></tr>\n",fp_top3);
-   fprintf(fp_top3,"<tr><td class=\"header_c\">%s: %s, %s</td></tr>\n",_("Sort"),TopuserSortField,TopuserSortOrder);
+   fputs("<tr><td class=\"header_c\">",fp_top3);
+   fprintf(fp_top3,_("Sort: %s, %s"),sort_field,sort_order);
+   fputs("</td></tr>\n",fp_top3);
    fprintf(fp_top3,"<tr><th class=\"header_c\">%s</th></tr>\n",_("Top users"));
    close_html_header(fp_top3);
 
@@ -306,6 +316,11 @@ void topuser(void)
          inperc=(tnbytes) ? incac * 100. / tnbytes : 0.;
          ouperc=(tnbytes) ? oucac * 100. / tnbytes : 0.;
          fprintf(fp_top3,"<td class=\"data\">%3.2lf%%</td><td class=\"data\">%3.2lf%%</td>",inperc,ouperc);
+#ifdef ENABLE_DOUBLE_CHECK_DATA
+         if (fabs(inperc+ouperc-100.)>=0.01) {
+            debuga(_("The total of the in-cache and cache-miss is not 100%% at position %d (user %s)\n"),posicao,uinfo->label);
+         }
+#endif
       }
       if((TopUserFields & TOPUSERFIELDS_USED_TIME) != 0)
          fprintf(fp_top3,"<td class=\"data\">%s</td>",buildtime(tnelap));
@@ -343,6 +358,11 @@ void topuser(void)
          inperc=(ttnbytes) ? ttnincache * 100. / ttnbytes : 0.;
          ouperc=(ttnbytes) ? ttnoucache *100. / ttnbytes : 0.;
          fprintf(fp_top3,"<th class=\"header_r\">%3.2lf%%</th><th class=\"header_r\">%3.2lf%%</th>",inperc,ouperc);
+#ifdef ENABLE_DOUBLE_CHECK_DATA
+         if (fabs(inperc+ouperc-100.)>=0.01) {
+            debuga(_("The total of the in-cache and cache-miss is not 100%%\n"));
+         }
+#endif
       }
       if((TopUserFields & TOPUSERFIELDS_USED_TIME) != 0)
          fprintf(fp_top3,"<th class=\"header_r\">%s</th>",buildtime(ttnelap));
