@@ -1146,12 +1146,12 @@ char *fixtime(long long int elap)
 
 void date_from(char *date, int *dfrom, int *duntil)
 {
-   int d0;
-   int m0;
-   int y0;
-   int d1;
-   int m1;
-   int y1;
+   int d0=0;
+   int m0=0;
+   int y0=0;
+   int d1=0;
+   int m1=0;
+   int y1=0;
 
    if (isdigit(date[0])) {
       int next=-1;
@@ -1271,6 +1271,9 @@ void date_from(char *date, int *dfrom, int *duntil)
          y1=Date0->tm_year+1900;
          m1=Date0->tm_mon+1;
          d1=Date0->tm_mday;
+      } else {
+         debuga(_("Invalid date range passed on command line\n"));
+         exit(EXIT_FAILURE);
       }
    }
 
@@ -1676,27 +1679,6 @@ void output_html_url(FILE *fp_ou,const char *url)
    }
 }
 
-void baddata(void)
-{
-   char dir[1024];
-
-   printf("SARG: ------------------------------------------------------------------------------\n");
-   printf(_("SARG: MALICIUS CODE DETECTED.\n"));
-   printf(_("SARG: I think someone is trying to execute arbitrary code in your system using sarg.\n"));
-   printf(_("SARG: please review your access.log and/or your useragent.log file.\n"));
-   printf(_("SARG: process stoped. No actions taken.\n"));
-   printf("SARG: ------------------------------------------------------------------------------\n");
-
-   if (snprintf(dir,sizeof(dir),"%s/sarg",tmp)>=sizeof(dir)) {
-      debuga(_("temporary directory too long: %s/sarg\n"),tmp);
-      exit(EXIT_FAILURE);
-   }
-   unlinkdir(dir,0);
-   unlinkdir(outdirname,0);
-
-   exit(EXIT_FAILURE);
-}
-
 void url_hostname(const char *url,char *hostname,int hostsize)
 {
    int i;
